/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/

var BioAssays = function()
{
	var bioassays = {};
	
	/**
		Initialize the page.
	*/
	bioassays.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', bioassays.save);
			Buttons.addClickHandler('close', App.closeWindow);

			// Tab validation
			TabControl.addTabActivateListener('settings.annotations', Annotations.autoLoadEditFrame);
			TabControl.addTabActivateListener('settings.inheritedAnnotations', Annotations.autoLoadInheritFrame);
			TabControl.addTabValidator('settings.info', bioassays.validateBioAssay);
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'BIOASSAY', 'item-id': itemId};
			
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnPlotter', bioassays.openPlotTool, attributes);
			
			TabControl.addTabActivateListener('main.annotations', AnnotationsList.loadOnce);
			TabControl.addTabActivateListener('main.spotdata', bioassays.viewSpotData, attributes);
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'BIOASSAY'};
			var tableAttributes = {'table-id': 'bioassays'};
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnFilter', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnAnalyze', Buttons.runListPlugin, tableAttributes);

			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
			
			TabControl.setSwitchFunction('main', bioassays.switchTab);
		}
	}
	
	bioassays.initElements = function(element, autoInit)
	{
		if (autoInit == 'plotter')
		{
			Buttons.addClickHandler(element, bioassays.openPlotTool);
		}
		else if (autoInit == 'spotdata')
		{
			Buttons.addClickHandler(element, bioassays.viewSpotData);
		}
		else if (autoInit == 'edit-experimental-factor')
		{
			Buttons.addClickHandler(element, bioassays.editExperimentalFactor);
		}
	}

	bioassays.switchTab = function(event)
	{
		var target = event.target;
		var tabId = target.id.substring(5);

		var frm = document.forms['bioassays'];

		var url;
		if (tabId.indexOf('bioassayset.') == 0)
		{
			url = '../bioassaysets/index.jsp?ID='+App.getSessionId();
			url += '&cmd=ViewItem&item_id='+frm.bioassayset_id.value;
			url += '&tab='+tabId.substring(12); // Strip 'bioassayset.'
		}
		else if (tabId == 'spotdata')
		{
			url = '../spotdata/index.jsp?ID='+App.getSessionId();
			url += '&bioassayset_id='+frm.bioassayset_id.value;
		}
		
		if (url) location.replace(url);
	}

	
	bioassays.openPlotTool = function(event)
	{
		var url = '../plotter/index.jsp?ID='+App.getSessionId();
		url += '&bioassay_id='+Data.get(event.currentTarget, 'item-id');
		Dialogs.openPopup(url, 'Plotter', 1050, 700);
	}
	
	bioassays.viewSpotData = function(event)
	{
		var url = '../spotdata/index.jsp?ID='+App.getSessionId();
		url += '&bioassay_id='+Data.get(event.currentTarget, 'item-id');
		location.href = url;
	}

	bioassays.editExperimentalFactor = function(event)
	{
		var url = App.getRoot() + 'common/annotations/annotate.jsp?ID='+App.getSessionId();
		url += '&item_type='+Data.get(event.currentTarget, 'item-type');
		url += '&item_id='+Data.get(event.currentTarget, 'item-id');
		url += '&annotationtype_id='+Data.get(event.currentTarget, 'annotation-type');
		url += '&standalone=1';
		Dialogs.openPopup(url, 'EditAnnotation', 750, 500);
	}
	
	bioassays.validateBioAssay = function()
	{
		var frm = document.forms['bioAssay'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		return true;
	}
	
	bioassays.save = function()
	{
		var frm = document.forms['bioAssay'];
		if (TabControl.validateActiveTab('settings'))
		{
			Annotations.saveModifiedAnnotationsToForm(frm);
			Annotations.saveInheritedAnnotationsToForm(frm);
			frm.submit();
		}
	}


	return bioassays;
}();

Doc.onLoad(BioAssays.initPage);
Doc.addElementInitializer(BioAssays.initElements);

